<?php
// controllers/AttendanceController.php

require_once '../models/AttendanceModel.php';
require_once '../vendor/autoload.php'; // Include TCPDF library

use TCPDF;

class AttendanceController {
    private $model;

    public function __construct($pdo) {
        $this->model = new AttendanceModel($pdo);
    }

    // Admin Login
    public function login() {
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $username = $_POST['username'];
            $password = md5($_POST['password']);

            $stmt = $this->model->pdo->prepare("SELECT * FROM admin WHERE username = :username AND password = :password");
            $stmt->execute([':username' => $username, ':password' => $password]);
            $admin = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($admin) {
                session_start();
                $_SESSION['admin_logged_in'] = true;
                header("Location: index.php?action=form");
                exit;
            } else {
                echo "Invalid credentials!";
            }
        }
        include '../views/login.php';
    }

    // Logout
    public function logout() {
        session_start();
        session_destroy();
        header("Location: index.php");
        exit;
    }

    // Show attendance form
    public function showForm() {
        include '../views/attendance_form.php';
    }

    // Submit attendance
    public function submitAttendance() {
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $employeeId = $_POST['employee_id'];
            $date = $_POST['date'];
            $timeIn = $_POST['time_in'];
            $timeOut = $_POST['time_out'];

            try {
                $this->model->addAttendance($employeeId, $date, $timeIn, $timeOut);
                echo "Attendance recorded successfully!";
            } catch (PDOException $e) {
                echo "Failed to record attendance: " . $e->getMessage();
            }
        }
    }

    // Show attendance list
    public function showAttendanceList() {
        $attendance = $this->model->getAllAttendance();
        include '../views/attendance_list.php';
    }

    // Show monthly attendance report
    public function showMonthlyReport() {
        $month = $_GET['month'] ?? date('m');
        $year = $_GET['year'] ?? date('Y');
        $report = $this->model->getMonthlyAttendance($month, $year);
        include '../views/monthly_attendance.php';
    }

    // Download monthly attendance report as PDF
    public function downloadMonthlyPDF() {
        $month = $_GET['month'] ?? date('m');
        $year = $_GET['year'] ?? date('Y');
        $report = $this->model->getMonthlyAttendance($month, $year);

        $pdf = new TCPDF();
        $pdf->SetCreator(PDF_CREATOR);
        $pdf->SetTitle('Monthly Attendance Report');
        $pdf->AddPage();
        $pdf->SetFont('helvetica', '', 12);

        $html = '<h1 style="text-align:center;">Monthly Attendance Report</h1>';
        $html .= '<table border="1" cellpadding="5">';
        $html .= '<tr>
                    <th>Employee Name</th>
                    <th>Total Days Worked</th>
                    <th>Total Hours Worked</th>
                  </tr>';

        foreach ($report as $record) {
            $html .= '<tr>
                        <td>' . htmlspecialchars($record['name']) . '</td>
                        <td>' . htmlspecialchars($record['total_days_worked']) . '</td>
                        <td>' . htmlspecialchars($record['total_hours_worked']) . '</td>
                      </tr>';
        }

        $html .= '</table>';
        $pdf->writeHTML($html, true, false, true, false, '');
        $pdf->Output('monthly_attendance_report.pdf', 'D');
    }

    // Show best staff report
    public function showBestStaff() {
        $month = $_GET['month'] ?? date('m');
        $year = $_GET['year'] ?? date('Y');
        $bestStaff = $this->model->getBestStaff($month, $year);
        include '../views/best_staff.php';
    }

    // Download best staff report as PDF
    public function downloadBestStaffPDF() {
        $month = $_GET['month'] ?? date('m');
        $year = $_GET['year'] ?? date('Y');
        $bestStaff = $this->model->getBestStaff($month, $year);

        $pdf = new TCPDF();
        $pdf->SetCreator(PDF_CREATOR);
        $pdf->SetTitle('Best Staff Report');
        $pdf->AddPage();
        $pdf->SetFont('helvetica', '', 12);

        $html = '<h1 style="text-align:center;">Best Staff Report</h1>';
        if ($bestStaff) {
            $html .= '<p><strong>Name:</strong> ' . htmlspecialchars($bestStaff['name']) . '</p>';
            $html .= '<p><strong>Total Hours Worked:</strong> ' . htmlspecialchars($bestStaff['total_hours_worked']) . '</p>';
        } else {
            $html .= '<p>No data available for the selected month.</p>';
        }

        $pdf->writeHTML($html, true, false, true, false, '');
        $pdf->Output('best_staff_report.pdf', 'D');
    }
}
?>