<?php
// models/AttendanceModel.php

class AttendanceModel {
    private $pdo;

    public function __construct($pdo) {
        $this->pdo = $pdo;
    }

    // Add attendance record
    public function addAttendance($employeeId, $date, $timeIn, $timeOut = null) {
        $stmt = $this->pdo->prepare("INSERT INTO attendance (employee_id, date, time_in, time_out) VALUES (:employee_id, :date, :time_in, :time_out)");
        return $stmt->execute([
            ':employee_id' => $employeeId,
            ':date' => $date,
            ':time_in' => $timeIn,
            ':time_out' => $timeOut
        ]);
    }

    // Fetch all attendance records
    public function getAllAttendance() {
        $stmt = $this->pdo->query("SELECT e.name, a.date, a.time_in, a.time_out, a.total_hours FROM attendance a JOIN employees e ON a.employee_id = e.id");
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // Fetch monthly attendance report
    public function getMonthlyAttendance($month, $year) {
        $stmt = $this->pdo->prepare("SELECT e.name, COUNT(a.id) AS total_days_worked, SUM(a.total_hours) AS total_hours_worked 
                                     FROM attendance a JOIN employees e ON a.employee_id = e.id 
                                     WHERE MONTH(a.date) = :month AND YEAR(a.date) = :year 
                                     GROUP BY e.id");
        $stmt->execute([':month' => $month, ':year' => $year]);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // Fetch best staff for a given month
    public function getBestStaff($month, $year) {
        $stmt = $this->pdo->prepare("SELECT e.name, SUM(a.total_hours) AS total_hours_worked 
                                     FROM attendance a JOIN employees e ON a.employee_id = e.id 
                                     WHERE MONTH(a.date) = :month AND YEAR(a.date) = :year 
                                     GROUP BY e.id ORDER BY total_hours_worked DESC LIMIT 1");
        $stmt->execute([':month' => $month, ':year' => $year]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }
}
?>